/*

################################################################
################################################################
################################################################

!!!!WARNING!!!!

DO NOT EDIT html/css/style.css DIRECTLY. That file is
auto-generated from assets/sass/style.scss and your changes will
be over-written.

To modify styles, make changes to assets/sass/style.scss file.
See https://github.com/perl6/doc/blob/master/CONTRIBUTING.md#website-styles
and https://github.com/perl6/doc/blob/master/CONTRIBUTING.md#mojolicious--web-server
for details


################################################################
################################################################
################################################################

*/


html, body {
    margin: 0;
    background: #EFEFEF!important;
    font-family: sans-serif !important; /*override font from perl.css
        stylesheet, until we can get rid of it*/
}

html {
    padding: 0;
    width: 100%;
    position: relative;
    min-height: 100%;
}

body {
    padding: 1px 10px 0;
    margin: -1px 0 0;
    width: auto;
}

.title {
    margin-top: 0;
    text-align: center;
}
.subtitle {
    text-align: center;
    font-style: italic;
}

pre {
    background-color: #F5F2F0;
    border: 1px solid #CFCFCF;
    padding: 0.6ex;
    color: black;
    overflow: auto;
    white-space: pre-wrap;
    word-break: break-all;
}

code {
    color: #666;
}

a code {
    color: #00e;
}

pre {
    a {
        text-decoration: underline;
        color: black;
    }

    a:hover {
        text-decoration: none;
        color: inherit;
    }
}

img, svg {
    max-width: 100%;
}

table.pod-table tr:nth-child(odd) {
    background-color: #f8f8f8;
}
table.pod-table tr:nth-child(even) {
    background-color: none;
}

td, th {
    padding: 0.4em;

    p {
        margin: 0;
    }
}

.pretty-box {
    border: 0.2em solid;
    background-style: solid;
    border-radius: 1em;
    box-shadow: 0.5em 0.5em 1em #888888;
    padding: 2em;
}

.red {
    border-color: #E43B59;
    background-color: #E47286;
}

.green {
    border-color: #8BC313;
    background-color: #C0E472;
}

.dark-green {
    border-color: #8BC313;
    background-color: #A0CE3D;
}

.darker-green {
    border-color: #8BC313;
    background-color: #8BC313;
}

.blue {
    border-color: #63A4FF;
    background-color: #80B5FF;
}

.yellow {
    border-color: #F2C100;
    background-color: #F5EF7B;
}

#header {
    font-family: sans-serif;
    font-weight: bold;
    border-radius: 0 0 4em 4em;
    margin: -2em auto 0; /*extra top padding and negative margin preserves bleed-off illusion for shadow*/
    padding: 3em 0em 0em 0em;
    line-height: 2em;
    overflow: hidden;
    border-top: none;
}

#header > a {
    color: #000000;
    text-decoration: none;
    font-size: 2em;
    margin-left: 1.5em;
}

#logo {
    display: inline-block;
    margin: -0.75em 0 -0.5em -0.5em;
    border: none;
    vertical-align: middle;
}

#search #not-found-message {
    background: #A00;
    color: white;
    padding: 2px 15px;
    border-radius: 3px;
    position: absolute;
    bottom: -7ex;
    left: 0;
    white-space: nowrap;
    font-size: 80%;
    font-weight: normal;
    display: none;
}

#search.not-found #not-found-message {
    display: block;
}

#not-found-message {
    a {
        color: white;
        text-decoration: underline;
        font-weight: bold;
    }

    a:hover,
    a:active {
        text-decoration: none;
    }
}

#search {
    position: relative;
    float: right;
    margin-right: 1.5em;
    margin-bottom: 0.5em;
    width: 32%;
    min-width: 9em;
    max-width: 35em;
}

#search.two-row {
    width: 84%;
    margin-top: 10px;
}

#search {
    text-align: right;

    label {
        float: left;
        font-size: 1.25em;
    }

    div {
        overflow: hidden;
/*
        border-width: 0.1em;
        border-style: solid;
        border-radius: 0.5em;
        padding: 0 0.5em;
        background-color: #FFFFFF;
*/
    }
}

#query {
    outline: none;

    border-width: 0.1em;
    border-style: solid;
    border-radius: 0.5em;
    border-color: #8BC313;

    margin: 0;
    padding: 0.25em 0.5em 0.25em 0.5em;
    width: 95%;
    background-color: #FFFFFF;
    color: #777777;

    -webkit-transition: all .2s ease-out;
    -moz-transition: all .2s ease-out;
    -ms-transition: all .2s ease-out;
    -o-transition: all .2s ease-out;
    transition: all .2s easeout;
}

#query:focus {
    color: #000000;
    text-align: left;
    width: 95%;
}

#query::input-placeholder {
    text-align: right;
}

#query::-moz-placeholder {
    text-align: right;
}

#query::-webkit-placeholder {
    text-align: right;
}

#query::-ms-placeholder {
    text-align: right;
}

.ui-autocomplete-category {
    font-weight: bold;
    font-style: italic;
    background-color: #8BC313;
    padding: 2px 5px;
    line-height: 1.5;
}
.ui-state-focus {
    font-weight: normal !important; /* override css/custom-theme/jquery-ui.css */
    font-style: italic;
}
.ui-menu .ui-menu-item {
    padding-left: 1em !important; /* override css/custom-theme/jquery-ui.css */
}

.menu {
    border: none;
    text-align: center;
    display: block;
    font-weight: normal;
}

.menu-items {
    display: inline-block;
    margin-right: auto;
    margin-left: auto;
    margin-bottom: -0.1em;
    width: 100%;
    height: 2.6em;
    line-height: 1.8em;

    + .menu-items  {
        height: auto;
    }
}

.menu-item {
    display: inline-block;
    padding-right: 1.0em;
    font-size: 1.1em;
    margin: 0.4em 0;

    + .menu-item {
        border-left: 2px ridge rgba(192,228,114,0.6);  /* #C0E472 */
        padding-left: 1.1em;
    }
}

.menu-item.selected {
    border-radius: 1em 1em 0 0;
    box-shadow: 0.5em 0.5em 1em #888888;
    display: inline-block;
    border-left: none;
    border-bottom: solid inherit;
    color: black;
    text-decoration: none;
    padding-left:  0.9em;
    padding-right: 0.9em;
    margin-top: 0.3em;
    line-height: 2.1em;

    + .menu-item {
        border-left: none;
    }
}

#formalities { font-style: italic; }

#content {
    margin: 2em auto;
    overflow: hidden;
    max-width: 800px;
    background: #FFFFFF;
//    background-image: url(/images/camelia-faded.png);
    background-repeat: no-repeat;
    background-position: right 2em top 2em;

    dt {
        font-weight: bold;
        margin-bottom: 0.2em;
    }

    dd {
        margin-bottom: 1em;
    }

    hr {
        border: none;
        margin: 0 3em;
        padding: 0;
        height: 20px;
        background-color: transparent;
        background-image: radial-gradient(#F5EF7B 30%, transparent 30%);
        background-size: 25px 25px;
        background-repeat: round no-repeat;
        background-position: 0 center;
    }

    p:nth-child(2) {
        margin-top: 0;
        padding-top: 0;
    }

    h1, h2, h3, h4, h5, h6 {
        a {
            color: black;
        }
    }

    h1 {
        padding-top: 0.25em;
    }
}

@media (min-width: 110em) {
    /* #content:has(#TOC) {*/
    #content {
        max-width: none;
        min-width: 60em;
        width: 60em;
        // overflow: visible;
        // margin-left: 0em;
        display: table;
        background-image: none;
    }
    div.pod-body {
        min-width: 60em;
        max-width: 60em;
        margin-left: 22em;
    }

    div.pod-body.no-toc {
        margin-left: 0em;
    }

    nav.indexgroup {
        float: left;
    }

    table#TOC {
        max-width: 20em;

        a {
            color: black;
        }
    }
}

.title-anchor {
    visibility: hidden;
    color: #333;
    font-size: 60%;
    margin-left: 10px;
    display: inline-block;
    text-decoration: none;
    vertical-align: 0.5ex;
    outline: none;
}

h1:hover, h2:hover, h3:hover, h4:hover, h5:hover, h6:hover {
    .title-anchor {
        visibility: visible;
    }
}

footer.pretty-box {
    padding: 5px;
    text-align: center;
    font-size: 80%;
    margin: 0 auto 20px;

    p {
        margin: 3px 0;
    }
}

#TOC_Title {
    font-size: 120%;
    white-space: nowrap;

    a {
        font-weight: normal;
        font-size: 90%;
        outline: 0;
    }
}

table#TOC {
    border-collapse: collapse;
    margin: 0 0 0 12pt;

    caption {
        text-align: left;
    }

    tr {
        background-color: transparent;
    }

    td {
        padding: 0.25pt 5pt 0 0;
        font-size: 11pt;
    }

    tr.toc-level-1:first-child td {
        padding-top: 0;
    }

    td.toc-text {
        position: relative;
        left: 6pt;
    }

    tr.toc-level-1 {
        td {
            padding-top: 4pt;
            font-weight: bold;
        }

        td.toc-text {
            position: relative;
            left: 0;
        }
    }

    tr.toc-level-2 td {
        padding-top: 3pt;
    }

    td.toc-number {
        display: none;
    }

    code {
        color: black;
    }
}

div.highlight span.c-Singleline, div.highlight span.c {
    color: #204040;
}

@media (max-width : 560px) {
    #header {
        border-radius: 10px;

        > a {
            font-size: 1.1em;
            display: block;
            padding: 5px 10px 0;
            margin: 0;
            text-align: center;
        }
    }

    #home_logo {
        display: none;
    }

    body { padding: 0; }

    .pretty-box {
        padding: 3px;
    }

    .menu-items {
        height: auto;
        padding: 0 10px;

        .menu-item + .menu-item {
            border: none;
        }
    }

    .menu-item.selected {
        box-shadow: none;
        border-radius: 3px;
    }

    table#TOC {
        tr[class^=toc-level] td {
            padding: 8px 0;
        }

        tr.toc-level-1 td {
            padding-top: 18px;
        }
    }
}
